@@ -1,7 +1,7 @@
 """
 Base Module
 -----------
-The ``ailca.chem.base`` module includes basic information and utilities to process chemical data.
+It includes basic information and utilities to process chemical data.
 Several pre-defined chemical and physical features can be accessed by the global variables of this module.
 """
 
