@@ -49,7 +49,7 @@ def get_crystal_graph(path_cif: str,
     :param path_cif: (*str*) Path of CIF containing the crystal structure.
     :param elem_attrs: (*torch.Tensor*) A table containing elemental attributes in each row.
     :param rbf_means: (*torch.Tensor*) Mean vectors to generate edge features based on RBF kernel.
-    :param atomic_cutoff: (*float*) Maximum radius in Angstrom to determine neighborhood atoms.
+    :param atomic_cutoff: (*float*) Maximum radius in Angstrom to determine neighborhood atoms (*default* = ``4.0``).
     :return: (*torch_geometric.data.Data*) A graph object of the crystal structure.
     """
 
@@ -177,9 +177,9 @@ def load_dataset(path_metadata_file: str,
     :param elem_attrs:  (*torch.Tensor*) A 2-dimensional tensor containing the elemental attributes of the elements.
     :param idx_mat_id: (*int*) An index of the material identifier in the metadata file.
     :param idx_target: (*int, optional*) An index of the target values in the data file (*default* = ``None``).
-    :param atomic_cutoff: (*float*) Maximum radius in Angstrom to define the neighborhood atoms (*default* = ``4.0``).
-    :param n_kerl_centers: (*int*) The number of kernel centers in radial basis function to the generate edge features (*default* = ``128``).
-    :param verbose: (*bool*) A flag variable to present the system log in data loading (*default* = ``True``).
+    :param atomic_cutoff: (*float, optional*) Maximum radius in Angstrom to define the neighborhood atoms (*default* = ``4.0``).
+    :param n_kerl_centers: (*int, optional*) The number of kernel centers in radial basis function to the generate edge features (*default* = ``128``).
+    :param verbose: (*bool, optional*) A flag variable to present the system log in data loading (*default* = ``True``).
     :return: (*Dataset*) A dataset object.
     """
 
