@@ -31,7 +31,6 @@ def load_dataset(path_metadata_file: str,
                  path_imgs: str,
                  idx_img_id: int,
                  idx_target: int = None,
-                 ext_img: str = 'png',
                  verbose: bool = True) -> Dataset:
     """
     Load the dataset containing the numerical features.
@@ -41,12 +40,10 @@ def load_dataset(path_metadata_file: str,
     :param path_imgs: (*str*) A directory of the image files.
     :param idx_img_id: (*int*) An index of the image identifiers in the metadata file.
     :param idx_target: (*int, optional*) An index of the target values in the data file (*default* = ``None``).
-    :param ext_img: (*str, optional*) Extension of the image file (*default = ``png``).
     :param verbose: (*bool*) A flag variable to present the system log in data loading (*default* = ``True``).
     :return: (*Dataset*) A dataset object.
     """
 
-    _ext_img = '.' + ext_img
     metadata_file = pandas.read_excel(path_metadata_file)
     metadata = numpy.array(metadata_file)
     names_feats = [metadata_file.columns.values[idx_img_id]]
@@ -60,7 +57,7 @@ def load_dataset(path_metadata_file: str,
 
     # Read images in the dataset.
     for i in iter_range:
-        img = get_image_data(path_imgs + '/' + metadata[i, idx_img_id] + _ext_img)
+        img = get_image_data(path_imgs + '/' + metadata[i, idx_img_id])
 
         if idx_target is None:
             list_data.append(Data(x=img, idx=i, dtype=DTYPE_IMG))
@@ -72,5 +69,4 @@ def load_dataset(path_metadata_file: str,
                    idx_target=idx_target,
                    names_feats=names_feats,
                    name_target=name_target,
-                   types_feats=[DTYPE_IMG for i in range(0, len(names_feats))],
-                   ext_img=ext_img)
+                   types_feats=[DTYPE_IMG for i in range(0, len(names_feats))])
