@@ -79,10 +79,10 @@ class HparamOptProblem(Problem):
         opt_hparams = dict()
 
         for i in range(0, self.n_hparams):
-            opt_hparams[self.hparam_names[i]] = int(_sol[i])
-
             if isinstance(self.param_space[self.hparam_names[i]][0], int):
-                opt_hparams[self.hparam_names[i]] = int(opt_hparams[self.hparam_names[i]])
+                opt_hparams[self.hparam_names[i]] = int(_sol[i])
+            else:
+                opt_hparams[self.hparam_names[i]] = float(_sol[i])
 
         return self.run_model(opt_hparams)
 
